@@ -12,7 +12,7 @@ use Aniki::Schema;
 use Aniki::QueryBuilder;
 use Aniki::QueryBuilder::Canonical;
 
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 use SQL::Maker::SQLType qw/sql_type/;
 use DBIx::Handler;
@@ -310,8 +310,8 @@ sub insert_and_emulate_row {
         if (exists $row->{$field->name}) {
             $row_data{$field->name} = $row->{$field->name};
         }
-        elsif (my $default_value = $field->default_value) {
-            $row_data{$field->name} = $default_value;
+        elsif (defined(my $default_value = $field->default_value)) {
+            $row_data{$field->name} = ref $default_value eq 'SCALAR' ? undef : $default_value;
         }
         elsif ($field->is_auto_increment) {
             $row_data{$field->name} = $self->last_insert_id($table_name, $field->name);
